import File from './file.js';
import S3 from './s3.js';
import FetcherError from './error.js';
const file = new File();
const s3 = new S3();
const certFetchers = [
    { name: 'file', fetcher: file },
    { name: 's3', fetcher: s3 },
];
export class CertFetcherManager {
    constructor() {
        this.fetchers = certFetchers;
    }
    addFetcher(name, fetcher) {
        const newFetcher = {
            name,
            fetcher,
        };
        this.fetchers.push(newFetcher);
    }
    getFetcher(name) {
        const fetcher = this.fetchers.find((item) => item.name === name);
        if (!fetcher) {
            throw new FetcherError(`A certificate fetcher with the name '${name}' is not found`, this.getFetcher);
        }
        return fetcher.fetcher;
    }
}
