import { S3Client, GetObjectCommand } from '@aws-sdk/client-s3';
export default class S3CertFetcher {
    async readCertificate(opts) {
        const s3Client = new S3Client({ region: opts.region || 'us-west-1' });
        const getCertInput = new GetObjectCommand({
            Bucket: opts.certBucket,
            Key: opts.certKey,
        });
        const getKeyInput = new GetObjectCommand({
            Bucket: opts.keyBucket,
            Key: opts.keyKey,
        });
        const { Body: certStream } = await s3Client.send(getCertInput).catch(() => {
            throw Error(`Cert file '${opts.certKey}' in bucket '${opts.certBucket}' does not exist or is not accessible`);
        });
        const { Body: keyStream } = await s3Client.send(getKeyInput).catch(() => {
            throw Error(`Key file '${opts.keyKey}' in bucket '${opts.keyBucket}' does not exist or is not accessible`);
        });
        return {
            cert: await certStream?.transformToString(),
            key: await keyStream?.transformToString(),
        };
    }
}
