import Endpoint from '../core/endpoint.js';
class Course extends Endpoint {
    async get(opt) {
        const query = `${opt.year},${opt.quarter},${opt.curriculumAbbreviation},${opt.courseNumber}`;
        const result = await this.service.get(`course/${query}.json`);
        if (Endpoint.isApiError(result.data)) {
            throw new Error(result.data.description);
        }
        return result.data;
    }
    async search(opt) {
        const params = Endpoint.makeQueryStringObject({
            changed_since_date: opt.changedSinceDate || '',
            course_number: opt.courseNumber || '',
            course_title_contains: opt.contains || '',
            course_title_starts: opt.startsWith || '',
            curriculum_abbreviation: opt.curriculumAbbreviation || '',
            exclude_courses_without_sections: opt.excludeCoursesWithoutSections || '',
            future_terms: opt.futureTerms || 0,
            page_size: opt.pageSize || '',
            page_start: opt.pageStart || '',
            quarter: opt.quarter || '',
            transcriptable_course: opt.transcriptableCourse || '',
            year: opt.year || '',
        });
        const query = new URLSearchParams(params);
        const result = await this.service.get(`course.json?${query}`);
        if (Endpoint.isApiError(result.data)) {
            throw new Error(result.data.description);
        }
        return result.data;
    }
}
export default Course;
