import Endpoint from '../core/endpoint.js';
class Program extends Endpoint {
    all(opt) {
        const params = Endpoint.makeQueryStringObject({
            first_effective_quarter: opt.quarter || '',
            first_effective_year: opt.year || '',
            major_abbr: opt.majorAbbr || '',
            pathway: opt.pathway || '',
            quarter: opt.quarter || '',
            year: opt.year || '',
        });
        const query = new URLSearchParams(params);
        return this.service.get(`program.json?${query}`)
            .then((result) => {
            if (Endpoint.isApiError(result.data)) {
                throw new Error(result.data.description);
            }
            const { Programs: data } = result.data;
            return data;
        });
    }
    async get(options) {
        const opt = options;
        opt.pathway = opt.pathway || '00';
        const query = `${opt.majorAbbr},${opt.pathway},${opt.firstEffectiveYear},${opt.firstEffectiveQuarter}`;
        const result = await this.service.get(`program/${query}.json`);
        if (Endpoint.isApiError(result.data)) {
            throw new Error(result.data.description);
        }
        return result.data;
    }
    search(opt) {
        const params = Endpoint.makeQueryStringObject({
            first_effective_quarter: opt.firstEffectiveQuarter || '',
            first_effective_year: opt.firstEffectiveYear || '',
            major_abbr: opt.majorAbbr || '',
            pathway: opt.pathway || '',
            quarter: opt.quarter || '',
            year: opt.year || '',
        });
        const query = new URLSearchParams(params);
        return this.service.get(`program.json?${query}`)
            .then((result) => {
            if (Endpoint.isApiError(result.data)) {
                throw new Error(result.data.description);
            }
            const { Programs: data } = result.data;
            return data;
        });
    }
}
export default Program;
