import Endpoint from '../core/endpoint.js';
class Section extends Endpoint {
    async get(opt) {
        const course = `${opt.courseNumber}/${opt.sectionId}`;
        const query = `${opt.year},${opt.quarter},${opt.curriculumAbbreviation},${course}`;
        const result = await this.service.get(`course/${query}.json`);
        if (Endpoint.isApiError(result.data)) {
            throw new Error(result.data.description);
        }
        return result.data;
    }
    async search(opt) {
        const params = Endpoint.makeQueryStringObject({
            changed_since_date: opt.changedSinceDate || '',
            course_number: opt.courseNumber || '',
            curriculum_abbreviation: opt.curriculumAbbreviation || '',
            delete_flag: opt.deleteFlag || '',
            facility_code: opt.facilityCode || '',
            future_terms: opt.futureTerms || 0,
            include_secondaries: opt.includeSecondaries || '',
            page_size: opt.pageSize || '',
            page_start: opt.pageStart || '',
            quarter: opt.quarter || '',
            reg_id: opt.regId || '',
            room_number: opt.roomNumber || '',
            search_by: opt.searchBy || '',
            sln: opt.sln || '',
            transcriptable_course: opt.transcriptableCourse || '',
            year: opt.year || '',
        });
        const query = new URLSearchParams(params);
        const result = await this.service.get(`section.json?${query}`);
        if (Endpoint.isApiError(result.data)) {
            throw new Error(result.data.description);
        }
        return result.data;
    }
}
export default Section;
