import got, { isResponseOk, Options, } from 'got';
import { ApiResult } from './IService.js';
import { LIB_VERSION } from '../version.js';
export default class Service {
    constructor(config, log) {
        this.log = log;
        const options = new Options({
            https: {
                certificate: config.auth.cert,
                key: config.auth.key,
            },
            prefixUrl: config.baseUrl,
            headers: {
                'User-Agent': `${config.organizationName}/${LIB_VERSION}`,
                Accept: 'application/json',
            },
        });
        this.got = got.extend(options);
    }
    async get(endpoint, params) {
        const response = await this.got.get(endpoint, { searchParams: params });
        this.log.info(`GET -- ${response.url}`);
        this.log.debug(`body: ${response.body}`);
        if (!isResponseOk(response)) {
            this.log.error(response.body);
            return {
                result: ApiResult.failure,
                data: {
                    errorCode: response.statusCode,
                    description: response.body,
                },
            };
        }
        return {
            result: ApiResult.success,
            data: JSON.parse(response.body),
        };
    }
}
